@@ -190,6 +190,11 @@ public:
         return mMaxStripNum;
     }
 
+    bool ready() const
+    {
+        return mReady;
+    }
+
     void save();
 
 private:
@@ -226,6 +231,7 @@ private:
     bool mScaleComic = false;
     bool mIsLeftToRight = false;
     bool mIsTopToBottom = false;
+    bool mReady = false;
 
     KConfigGroup mCfg;
 };
