@@ -14,12 +14,9 @@
 #include <KNSCore/EntryInternal>
 #include <Plasma/DataEngine>
 
-namespace KNS3
-{
-}
 namespace KNSCore
 {
-class DownloadManager;
+class Engine;
 }
 
 namespace Plasma
@@ -51,14 +48,15 @@ private Q_SLOTS:
     void slotUpdatesFound(const KNSCore::EntryInternal::List &entries);
 
 private:
-    KNSCore::DownloadManager *downloadManager();
+    KNSCore::Engine *engine();
 
 private:
-    KNSCore::DownloadManager *mDownloadManager;
+    KNSCore::Engine *mEngine;
     KConfigGroup mGroup;
     int mUpdateIntervall;
     QDateTime mLastUpdate;
     QTimer *m_updateTimer;
+    bool mProvidersLoaded;
 };
 
 #endif
