@@ -36,12 +36,14 @@ void MonitorPrivate::handleServiceRegistered()
 {
     QDBusConnection bus = QDBusConnection::sessionBus();
 
+    // clang-format off
     const bool connected = bus.connect(s_serviceName,
                                        s_nightColorPath,
                                        s_propertiesInterface,
                                        QStringLiteral("PropertiesChanged"),
                                        this,
-                                       SLOT(handlePropertiesChanged(QString, QVariantMap, QStringList)));
+                                       SLOT(handlePropertiesChanged(QString,QVariantMap,QStringList)));
+    // clang-format on
     if (!connected) {
         return;
     }
@@ -68,12 +70,14 @@ void MonitorPrivate::handleServiceUnregistered()
 {
     QDBusConnection bus = QDBusConnection::sessionBus();
 
+    // clang-format off
     bus.disconnect(s_serviceName,
                    s_nightColorPath,
                    s_propertiesInterface,
                    QStringLiteral("PropertiesChanged"),
                    this,
-                   SLOT(handlePropertiesChanged(QString, QVariantMap, QStringList)));
+                   SLOT(handlePropertiesChanged(QString,QVariantMap,QStringList)));
+    // clang-format on
 
     setAvailable(false);
 }
@@ -130,7 +134,7 @@ void MonitorPrivate::setCurrentTemperature(int temperature)
         return;
     }
     m_currentTemperature = temperature;
-    emit currentTemperatureChanged();
+    Q_EMIT currentTemperatureChanged();
 }
 
 void MonitorPrivate::setTargetTemperature(int temperature)
@@ -139,7 +143,7 @@ void MonitorPrivate::setTargetTemperature(int temperature)
         return;
     }
     m_targetTemperature = temperature;
-    emit targetTemperatureChanged();
+    Q_EMIT targetTemperatureChanged();
 }
 
 bool MonitorPrivate::isAvailable() const
@@ -153,7 +157,7 @@ void MonitorPrivate::setAvailable(bool available)
         return;
     }
     m_isAvailable = available;
-    emit availableChanged();
+    Q_EMIT availableChanged();
 }
 
 bool MonitorPrivate::isEnabled() const
@@ -167,7 +171,7 @@ void MonitorPrivate::setEnabled(bool enabled)
         return;
     }
     m_isEnabled = enabled;
-    emit enabledChanged();
+    Q_EMIT enabledChanged();
 }
 
 bool MonitorPrivate::isRunning() const
@@ -181,7 +185,7 @@ void MonitorPrivate::setRunning(bool running)
         return;
     }
     m_isRunning = running;
-    emit runningChanged();
+    Q_EMIT runningChanged();
 }
 
 Monitor::Monitor(QObject *parent)
