@@ -1,18 +1,7 @@
 /*
- * Copyright 2019 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
+ * SPDX-FileCopyrightText: 2019 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
@@ -43,9 +32,7 @@ Q_SIGNALS:
 private Q_SLOTS:
     void handleServiceRegistered();
     void handleServiceUnregistered();
-    void handlePropertiesChanged(const QString &interfaceName,
-                                 const QVariantMap &changedProperties,
-                                 const QStringList &invalidatedProperties);
+    void handlePropertiesChanged(const QString &interfaceName, const QVariantMap &changedProperties, const QStringList &invalidatedProperties);
 
 private:
     void updateProperties(const QVariantMap &properties);
