@@ -33,7 +33,7 @@ void ApodProvider::pageRequestFinished(KJob *_job)
 {
     KIO::StoredTransferJob *job = static_cast<KIO::StoredTransferJob *>(_job);
     if (job->error()) {
-        emit error(this);
+        Q_EMIT error(this);
         return;
     }
 
@@ -48,7 +48,7 @@ void ApodProvider::pageRequestFinished(KJob *_job)
         KIO::StoredTransferJob *imageJob = KIO::storedGet(url, KIO::NoReload, KIO::HideProgressInfo);
         connect(imageJob, &KIO::StoredTransferJob::finished, this, &ApodProvider::imageRequestFinished);
     } else {
-        emit error(this);
+        Q_EMIT error(this);
     }
 }
 
@@ -56,12 +56,12 @@ void ApodProvider::imageRequestFinished(KJob *_job)
 {
     KIO::StoredTransferJob *job = static_cast<KIO::StoredTransferJob *>(_job);
     if (job->error()) {
-        emit error(this);
+        Q_EMIT error(this);
         return;
     }
 
     mImage = QImage::fromData(job->data());
-    emit finished(this);
+    Q_EMIT finished(this);
 }
 
 K_PLUGIN_CLASS_WITH_JSON(ApodProvider, "apodprovider.json")
