@@ -40,12 +40,12 @@ void UnsplashProvider::imageRequestFinished(KJob *_job)
 {
     KIO::StoredTransferJob *job = static_cast<KIO::StoredTransferJob *>(_job);
     if (job->error()) {
-        emit error(this);
+        Q_EMIT error(this);
         return;
     }
     QByteArray data = job->data();
     mImage = QImage::fromData(data);
-    emit finished(this);
+    Q_EMIT finished(this);
 }
 
 K_PLUGIN_CLASS_WITH_JSON(UnsplashProvider, "unsplashprovider.json")
